/*-------------------------------------------------------------------------+
| Copyright 2023 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.ext.quality.data;

import java.util.HashMap;
import java.util.Map;

import org.eclipse.emf.ecore.EObject;
import org.fortiss.tooling.kernel.model.IProjectRootElement;

/**
 * Class storing the metrics computed for the all suitable elements.
 * 
 * @author groh
 */
public class MetricData {

	/** A map to lookup the corresponding tree node for any {@link EObject}. */
	private Map<EObject, MetricTreeNode> treeNodeLookupTable;

	/** A map to lookup the corresponding root tree node for a project. */
	private Map<IProjectRootElement, DataRootElement> dataRootElementMap;

	/** Constructor. */
	public MetricData() {
		dataRootElementMap = new HashMap<>();
		treeNodeLookupTable = new HashMap<>();
	}

	/** Getter for {@link #treeNodeLookupTable}. */
	public Map<EObject, MetricTreeNode> getTreeNodeLookupTable() {
		return treeNodeLookupTable;
	}

	/** Getter for {@link #dataRootElementMap}. */
	public Map<IProjectRootElement, DataRootElement> getDataRootElementMap() {
		return dataRootElementMap;
	}
}
