/*--------------------------------------------------------------------------+
|                                                                          |
| Copyright 2022 fortiss GmbH						                       |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.ext.variability.constraint;

import static org.fortiss.tooling.kernel.extension.data.IConstraintViolation.ESeverity.WARNING;
import static org.fortiss.variability.util.VariabilityUtils.isNameLegalInPresenceCondition;

import java.util.ArrayList;
import java.util.List;

import org.fortiss.tooling.kernel.extension.base.ConstraintCheckerBase;
import org.fortiss.tooling.kernel.extension.base.ConstraintViolationBase;
import org.fortiss.tooling.kernel.extension.data.IConstraintViolation;
import org.fortiss.variability.model.presence.ILiteralReferencable;

/**
 * Syntax checker for {@link ILiteralReferencable}s in AF3.
 * Checks if its name is valid/legal regarding the presence condition syntax.
 * 
 * @author bayha
 */
public class LiteralReferencableChecker extends ConstraintCheckerBase<ILiteralReferencable> {

	/** {@inheritDoc} */
	@Override
	public List<IConstraintViolation<?>> apply(ILiteralReferencable modelElement) {

		List<IConstraintViolation<?>> ret = new ArrayList<IConstraintViolation<?>>();

		String literalName = modelElement.getName();
		if(!isNameLegalInPresenceCondition(literalName)) {
			String msg = "The name \"" + literalName +
					"\" contains illegal characters. Like this, the name cannot " +
					"be used in any presence condition. Names may only contain " +
					"\"a-z, A-Z, 0-9,_,-,@,$,/,\\,[,],. , ,, =\".";
			ret.add(new ConstraintViolationBase<ILiteralReferencable>(modelElement, WARNING, msg));
		}

		return ret;
	}
}
